@@ -52,14 +52,8 @@ class Config(object):
 class EnvVars(object):
     # system configuration
     region = os.environ.get("REGION", 'us').lower()
-    max_batch_size = int(os.environ.get('MAX_BATCH_SIZE', 500))
     redis_queues = os.environ.get('REDIS_QUEUES', 'trainer').split(';')
     mongodb_ssl = os.environ.get('MONGODB_SSL')
-    minio_access_key = os.environ.get('MINIO_ACCESS_KEY')
-    minio_secret_key = os.environ.get('MINIO_SECRET_KEY')
-    storange_server_uri = os.environ.get('STORAGE_SERVER_URI')
-    max_num_index = int(os.environ.get('MAX_NUM_INDEX', 2))
     job_ttl = os.environ.get("JOB_TTL", "48h")
     op_ttl = max(int(os.environ.get('OP_TTL', 432000)), 3600)
-    remote_server_uri = os.environ.get('REMOTE_SERVER_URI')
     mode = os.environ.get('MODE', "k8s")
\ No newline at end of file
