@@ -15,6 +15,7 @@ from rq import Queue, Connection
 from .agents.k8s_agent import K8S
 from .agents.docker_agent import Docker
 from .database.mongo_api import Database
+from .moniter import Monitor
 from .config import JobState
 from flask import send_file
 import os
@@ -49,6 +50,8 @@ class Connector(object):
             self.cluster_client = K8S()
         else:
             self.cluster_client = Docker()
+
+        self.monitor = Monitor(self.db, redis_url)
         self.param = param
 
         # add routes to flask App
